==> Localhero_1_03.zip: localhero_1_03_10.oxp/Scripts/harkov_shuttle2.js <==
/*
this.name           = "harkov_shuttle2";
this.author         = "Svengali";
this.copyright      = "Feb2008";
this.description    = "Localhero Part I - V1.03.10";
this.version        = "1.00";
*/
this.shipDied = function() { this.localhero_govkilled(); }
this.shipSpawned = function() { this.timer = new Timer(this, this.localhero_govtimer, 25); }
this.shipWillDockWithStation = function() { this.localhero_govdock(); }

this.localhero_govkilled = function()
{
	System.legacy_spawn('harkov_pod5', 1);
	let posto = this.ship.position.add(0,0,7);
	let allpods = System.shipsWithRole('harkov_pod5');
	allpods.reverse();
	allpods[0].setPosition(posto);
	missionVariables.localhero_special = "FAILED";
	missionVariables.localhero_goal += 40;
	delete this.shipDied;
	delete this.localhero_govkilled;
}

this.localhero_govtimer = function()
{
	this.timer.stop;
	player.call("playSound:", "harkov_comm.ogg");
	player.commsMessage("Major Hurst: Commander, some more bad news. District Governor Thekrath arrives with his shuttle. He must survive!");
	delete this.timer;
	delete this.shipSpawned;
	delete this.localhero_govtimer;
	}

this.localhero_govdock = function()
{
	player.call("playSound:", "harkov_comm.ogg");
	player.commsMessage("SHUTTLE HAS REACHED THE STATION");
	missionVariables.localhero_special = "RESCUED";
	missionVariables.localhero_goal -= 40;
	missionVariables.localhero_bonus += 1000;
	delete this.shipDied;
	delete this.localhero_govkilled;
	delete this.timer;
	delete this.shipSpawned;
	delete this.localhero_govtimer;
	delete this.shipWillDockWithStation;
	delete this.localhero_govdock;
}

==> Localhero_1_03_11.zip: localhero_1_03_11.oxp/Scripts/harkov_shuttle2.js <==
/*
this.name           = "harkov_shuttle2";
this.author         = "Svengali";
this.copyright      = "Feb2008";
this.description    = "Localhero Part I - V1.03.11";
this.version        = "1.00";
*/
this.shipDied = function() { this.localhero_govkilled(); }
this.shipSpawned = function() { this.timer = new Timer(this, this.localhero_govtimer, 25); }
this.shipWillDockWithStation = function() { this.localhero_govdock(); }

this.localhero_govkilled = function()
{
	System.legacy_spawn('harkov_pod5', 1);
	let posto = this.ship.position.add(0,0,7);
	let allpods = System.shipsWithRole('harkov_pod5');
	allpods.sort().reverse();
	allpods[0].setPosition(posto);
	missionVariables.localhero_special = "FAILED";
	missionVariables.localhero_goal += 40;
	delete this.shipDied;
	delete this.localhero_govkilled;
}

this.localhero_govtimer = function()
{
	this.timer.stop;
	player.call("playSound:", "harkov_comm.ogg");
	player.commsMessage("Major Hurst: Commander, some more bad news. District Governor Thekrath arrives with his shuttle. He must survive!");
	delete this.timer;
	delete this.shipSpawned;
	delete this.localhero_govtimer;
	}

this.localhero_govdock = function()
{
	let distance = Math.round(player.position.distanceTo(this.ship))
	if (distance < 5000)
	{
		missionVariables.localhero_bonus += 1000;
		player.commsMessage("THANKS TO ESCORT THE SHUTTLE, COMMANDER. THE SHUTTLE HAS REACHED THE STATION.");
	}
	else
	{
		player.commsMessage("THE SHUTTLE HAS REACHED THE STATION");
	}
	player.call("playSound:", "harkov_comm.ogg");
	missionVariables.localhero_special = "RESCUED";
	missionVariables.localhero_goal -= 40;
	missionVariables.localhero_bonus += 1000;
	delete this.shipDied;
	delete this.localhero_govkilled;
	delete this.timer;
	delete this.shipSpawned;
	delete this.localhero_govtimer;
	delete this.shipWillDockWithStation;
	delete this.localhero_govdock;
}
